@@ -10,12 +10,15 @@ import typing_extensions
 
 import aws_cdk.aws_backup._jsii
 import aws_cdk.aws_dynamodb._jsii
+import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_kinesis._jsii
+import aws_cdk.aws_kms._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "compliantdynamodb", "0.0.10", __name__[0:-6], "compliantdynamodb@0.0.10.jsii.tgz"
+    "compliantdynamodb", "0.0.11", __name__[0:-6], "compliantdynamodb@0.0.11.jsii.tgz"
 )
 
 __all__ = [
